@@ -1678,7 +1678,7 @@ Set the Data attribute of a variable.
         
         base = cfa_data.get('base', None)
         if base is not None:
-            cfa_data['base'] = pathjoin(dirname(g['filename'], base))
+            cfa_data['base'] = pathjoin(dirname(g['filename']), base)
             
         ncdimensions = variable.getprop('cfa_dimensions', '').split()
         dtype = ncvar.dtype
