@@ -754,7 +754,7 @@ written to the file.
     # serialization
     del cfa_array['_axes']
     del cfa_array['shape']
-    del cfa_array['Units']
+    del cfa_array['units']
     del cfa_array['dtype']
     cfa_array.pop('_cyclic', None)
     cfa_array.pop('_fill', None)
