@@ -214,7 +214,8 @@ Office (UK) fields files format files may be read.
 :Returns:
     
     out: `cf.FieldList`
-        A list of the fields fpound in the input file(s).
+        A list of the fields found in the input file(s). The list may
+        be empty.
 
 :Examples 2:
 
@@ -346,13 +347,13 @@ Office (UK) fields files format files may be read.
         #--- End: for            
     #--- End: for     
 
-    # Error check
-    if not ignore_read_error:
-        if not file_counter:
-            raise RuntimeError('No files found')
-        if not field_list:
-            raise RuntimeError('No fields found from '+str(file_counter)+' files')
-    #--- End: if
+#    # Error check
+#    if not ignore_read_error:
+#        if not file_counter:
+#            raise RuntimeError('No files found')
+#        if not field_list:
+#            raise RuntimeError('No fields found from '+str(file_counter)+' files')
+#    #--- End: if
 
     # Print some informative messages
     if verbose:
@@ -429,11 +430,12 @@ def read1(*args, **kwargs):
 def read_field(*args, **kwargs):
     '''Read a single field from netCDF, PP or UM fields files.
 
-If more than one field is found in the input files then an error is
-raised. 
+If not exactly one field is found in the input files then an error is
+raised. Files should be read with `cf.read` unless it is known that
+only one field will be created from them.
 
-`cf.read` should be used unless it is known that only one field will
-be created from the input file(s).
+Note that if field aggregation is on (as is it by default), then the
+number of fields is that after teh inputs have been aggregated.
 
 Files may be on disk or on a OPeNDAP server.
 
